@@ -18,9 +18,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA 02110-1301, USA
 
-from store import Store
-from component import Component
-from component import Checksum
-from component import Provide
-from component import Release
-from errors import ParseError, ValidationError
+from appstream.store import Store
+from appstream.component import Component
+from appstream.component import Checksum
+from appstream.component import Provide
+from appstream.component import Release
+from appstream.errors import ParseError, ValidationError
