@@ -164,9 +164,11 @@ class Component(object):
         self.kind = None
         self.provides = []
         self.name = None
+        self.pkgname = None
         self.summary = None
         self.description = None
         self.urls = {}
+        self.icons = {}
         self.metadata_license = None
         self.project_license = None
         self.developer_name = None
@@ -176,6 +178,8 @@ class Component(object):
         xml = '  <component type="firmware">\n'
         if self.id:
             xml += '    <id>%s</id>\n' % self.id
+        if self.pkgname:
+            xml += '    <pkgname>%s</pkgname>\n' % self.pkgname
         if self.name:
             xml += '    <name>%s</name>\n' % self.name
         if self.summary:
@@ -186,6 +190,8 @@ class Component(object):
             xml += '    <description>%s</description>\n' % self.description
         for key in self.urls:
             xml += '    <url type="%s">%s</url>\n' % (key, self.urls[key])
+        for key in self.icons:
+            xml += '    <icon type="%s">%s</icon>\n' % (key, self.icons[key]['value'])
         if len(self.releases) > 0:
             xml += '    <releases>\n'
             for rel in self.releases:
@@ -312,6 +318,10 @@ class Component(object):
             elif c1.tag == 'name' and not self.name:
                 self.name = _join_lines(c1.text)
 
+            # <pkgname>
+            elif c1.tag == 'pkgname' and not self.pkgname:
+                self.pkgname = _join_lines(c1.text)
+
             # <summary>
             elif c1.tag == 'summary' and not self.summary:
                 self.summary = _join_lines(c1.text)
@@ -326,3 +336,8 @@ class Component(object):
                 if 'type' in c1.attrib:
                     key = c1.attrib['type']
                 self.urls[key] = c1.text
+
+            elif c1.tag == 'icon':
+                key = c1.attrib.pop('type', 'unknown')
+                c1.attrib['value'] = c1.text
+                self.icons[key] = self.icons.get(key, []) + [c1.attrib]
